#
# spec file for package bspwm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 Luke Jones, luke.nukem.jones@gmail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           bspwm
Version:        0.9.5
Release:        lp151.2.3
Summary:        A tiling window manager based on binary space partitioning
License:        BSD-2-Clause
Group:          System/GUI/Other
Url:            https://github.com/baskerville/bspwm
Source0:        https://github.com/baskerville/bspwm/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        bspwm.desktop
BuildRequires:  pkgconfig
BuildRequires:  zsh
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-event)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcb-xinerama)
BuildRequires:  pkgconfig(xcb-xkb)
Recommends:     dmenu
Recommends:     lemonbar
Recommends:     sxhkd

%description
A tiling window manager based on binary space partitioning.
* It only responds to X events, and the messages it receives on a dedicated socket.
* bspc is a program that writes messages on bspwm's socket.
* bspwm doesn't handle any keyboard or pointer inputs: a third party program (e.g.
sxhkd) is needed in order to translate keyboard and pointer events to bspc invocations.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/GUI/Other
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    packageand(%{name}:bash)
BuildArch:      noarch

%description bash-completion
Bash completion for bspc

%package zsh-completion
Summary:        ZSH Completion for %{name}
Group:          System/GUI/Other
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:zsh)
BuildArch:      noarch

%description zsh-completion
ZSH completion for bspc

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/GUI/Other
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:zsh)
BuildArch:      noarch

%description fish-completion
Fish completion for bspc

%prep
%setup -q
# fix rpmlint E: env-script-interpreter
sed -i 's,^#! /usr/bin/env ,#!/usr/bin/,' ./examples/receptacles/{extract_canvas,induce_rules}

%build
export CPPFLAGS="%{optflags}"
make %{?_smp_mflags} V=1

%install
%make_install PREFIX=%{_prefix} DOCPREFIX=%{_docdir}/%{name}
install -pm 644 %{SOURCE1} contrib/freedesktop/bspwm.desktop
install -D -p -m 644 examples/bspwmrc \
        %{buildroot}%{_sysconfdir}/skel/.config/bspwm/bspwmrc
install -D -p -m 644 LICENSE %{buildroot}%{_docdir}/%{name}/LICENSE

%files
%{_bindir}/bspwm
%{_bindir}/bspc
%{_docdir}/%{name}
%{_mandir}/man1/bspwm.1%{?ext_man}
%{_mandir}/man1/bspc.1%{?ext_man}
%{_datadir}/xsessions/bspwm.desktop
%{_sysconfdir}/skel/.config/bspwm
%config %{_sysconfdir}/skel/.config/bspwm/bspwmrc

%files bash-completion
%{_datadir}/bash-completion

%files fish-completion
%{_datadir}/fish

%files zsh-completion
%{_datadir}/zsh

%changelog
* Wed Apr 11 2018 avindra@opensuse.org
- Update to 0.9.5
  * Fix resize by mouse behavioral change
  * Disable 4 default options (IGNORE_EWMH_FOCUS,
    REMOVE_DISABLED_MONITORS, REMOVE_UNPLUGGED_MONITORS,
    MERGE_OVERLAPPING_MONITORS)
* Thu Mar 29 2018 avindra@opensuse.org
- Update to 0.9.4
- Changes
  * The following events: node_{manage,unmanage} are now
    node_{add,remove}.
- Additions
  * New monitor/desktop/node descriptors: any, newest.
  * New node flag: marked.
  * New monitor descriptor: pointed.
  * New wm command: --reorder-monitors.
  * Receptacles are now described in the manual.
  * New --follow option added to node -{m,d,n,s} and desktop
  - {m,s}.
  * The subscribe command now has the following options: --fifo,
  - -count.
  * New settings: ignore_ewmh_fullscreen, mapping_events_count.
* Tue Mar 27 2018 avindra@opensuse.org
- split completion scripts into sub-packages
- fix lint errors
- cleanup with spec-cleaner
- compile with %%optflags
- delete _service file
- remove manual desktop database config
* Sun Sep 24 2017 aavindraa@gmail.com
- Created _service file
- Update to 0.9.3
- Changes
  * *click_to_focus* is now a button name. Specifying a boolean is
    deprecated but will still work (`true` is equivalent to `button1`).
- Additions
  * `node -r` now accepts a relative fraction argument.
  * An option was added to `query -{M,D,N}` in order to output names
    instead of IDs: `--names`.
  * New rule consequence: `rectangle=WxH+X+Y`.
  * New settings: `swallow_first_click` and `directional_focus_tightness`.
* Fri Feb 10 2017 luke.nukem.jones@gmail.com
- Update to 0.9.2
- Changes
  * Monitors, desktops and nodes have unique IDs, `bspc query -{N,D,M}`
    returns IDs and events reference objects by ID instead of name.
  * `bspc` fails verbosely and only returns a single non-zero exit code.
  * The `DIR` descriptor is based on [right-window](https://github.com/ntrrgc/right-window).
  * The `CYCLE_DIR` descriptor isn't limited to the current
    desktop/monitor anymore. (You can emulate the previous behavior
    by appending a `.local` modifier to the selector.)
  * `bspc query -{N,D,M}` accepts an optional reference argument
    used by certain descriptors/modifiers.
  * Monitors are ordered visually by default.
  * The following settings: `border_width`, `window_gap` and
    `*_padding` behave as expected.
  * External rules also receives the monitor, desktop and node
    selectors computed from the built-in rules stage as subsequent arguments.
  * The `focus_follows_pointer` setting is implemented via enter
    notify events.
- Additions
  * Nodes can be hidden/shown via the new `hidden` flag.
  * Node receptacles can be inserted with `node -i`. An example
    is given in `git show e8aa679`.
  * Non-tiled nodes can be moved/resized via `node -{v,z}`.
  * The reference of a selector can be set via the `{NODE,DESKTOP
    ,MONITOR}_SEL#` prefix, example: `bspc node 0x0080000c#south -c`
    will close the node at the south of `0x0080000c`.
  * Node descriptors: `<node_id>`, `pointed`.
  * Node modifiers: `hidden`, `descendant_of`, `ancestor_of`, `window`,
    `active`. Example: `bspc query -N 0x00400006 -n .descendant_of` returns
    the descendants of `0x00400006`.
  * Desktop descriptor: `<desktop_id>`.
  * Monitor descriptor: `<monitor_id>`.
  * Settings: `pointer_motion_interval`, `pointer_modifier`,
    `pointer_action{1,2,3}`, `click_to_focus`, `honor_size_hints`.
  * Event: `pointer_action`.
  * ICCCM/EWMH atoms: `WM_STATE`, `_NET_WM_STRUT_PARTIAL`.
  * `bspc` shell completions for `fish`.
- Removals
  * The `pointer` domain. Pointer actions are handled internally.
    You need to remove any binding that uses this domain from your
    `sxhkdrc`.
  * Settings: `history_aware_focus`, `focus_by_distance`. Both
    settings are merged into the new `DIR` implementation.
  * `monitor -r|--remove-desktops`: use `desktop -r|--remove` instead.
  * `wm -r|--remove-monitor`: use `monitor -r|--remove` instead.
* Wed Oct  5 2016 luke.nukem.jones@gmail.com
- change sxhkd and dmenu to be recommended, not required
- move to pkgconfig deps, add desktop-utils handling
* Fri Jul 15 2016 luke.nukem.jones@gmail.com
- Initial packaging of bspwm
